@@ -20,6 +20,7 @@ from giza.content.table import table_tasks
 from giza.content.hash import hash_tasks
 from giza.content.source import source_tasks
 from giza.content.toc import toc_tasks
+from giza.content.examples.tasks import example_tasks
 from giza.content.steps import steps_tasks
 from giza.content.dependencies import refresh_dependency_tasks
 from giza.content.sphinx import sphinx_tasks, output_sphinx_stream, finalize_sphinx_build
@@ -115,3 +116,4 @@ def build_prep_tasks(conf, app):
 def build_content_generation_tasks(conf, app):
     steps_tasks(conf, app.add('app'))
     toc_tasks(conf, app)
+    example_tasks(conf, app)
